package
Version:
v1.4.3
Opens a new window with list of versions in this module.
Published: Mar 24, 2018
License: Apache-2.0
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
-
func New(size int, network, address, password string, keyPairs ...[]byte) (nSessions.Store, error)
-
func NewWithDB(size int, network, address, password, db, keyPrefix string, keyPairs ...[]byte) (nSessions.Store, error)
New returns a new Redis store
New returns a new Redis store
Source Files
¶
Click to show internal directories.
Click to hide internal directories.